@@ -1,3 +1,4 @@
+\donttest{
 # Load Gorilla data
 data("gorillas")
 
@@ -17,7 +18,6 @@ ggplot() + gg(gorillas$mesh,
               ext.color = "blue"
               )
 
-\dontrun{
 # Use the x-coordinate of the vertices to colorize the triangles and
 # mask the plotted area by the survey boundary, i.e. only plot the inside
 
